@@ -153,9 +153,9 @@ id.st <- function(x, c_lower = 0.3, c_upper = 0.7, c_step = 5, c_fix = NULL, tra
   if(x$type == 'const'){
     Z_t <- rbind(rep(1, ncol(yl)), yl)
   }else if(x$type == 'trend'){
-    Z_t <- rbind(seq(1, ncol(yl)), yl)
+    Z_t <- rbind(seq(p + 1, Tob), yl)
   }else if(x$type == 'both'){
-    Z_t <- rbind(rep(1, ncol(yl)), seq(1, ncol(yl)), yl)
+    Z_t <- rbind(rep(1, ncol(yl)), seq(p + 1, Tob), yl)
   }else{
     Z_t <- yl
   }
