@@ -92,7 +92,7 @@ id.ngml_boot <- function(x, stage3 = FALSE, Z = NULL, restriction_matrix = NULL)
           trend[i] <- coef_x[[i]][(k*p+1), 1]
         }
         A <- cbind(trend, A)
-        Z_t <- rbind(seq(1, ncol(yl)), yl)
+        Z_t <- rbind(seq(p + 1, Tob), yl)
       }else if(type == "both"){
         v <- rep(1, k)
 
@@ -101,7 +101,7 @@ id.ngml_boot <- function(x, stage3 = FALSE, Z = NULL, restriction_matrix = NULL)
         }
 
         trend <- rep(1, k)
-        Z_t <- rbind(rep(1, ncol(yl)), seq(1, ncol(yl)), yl)
+        Z_t <- rbind(rep(1, ncol(yl)), seq(p + 1, Tob), yl)
         for(i in 1:k){
           trend[i] <- coef_x[[i]][(k*p+2), 1]
         }
