@@ -35,13 +35,13 @@ summary.svars <- function(object, ...){
  cat("\nStandard Errors of B:\n")
  print(svarsObject$B_SE)
  cat("\nPairwise Wald Test:\n")
- print(svarsObject$wald_statistic)
+ printCoefmat(svarsObject$wald_statistic, has.Pvalue = T)
    if(svarsObject$restrictions > 0){
-     cat("\nLikelihood Ratio Test Statistic: ")
-     cat(svarsObject$lRatioTestStatistic)
-     cat(", p-value:")
-     cat(svarsObject$lRatioTestPValue)
-
+     cat("\nLikelihood Ratio Test: \n")
+     #cat(svarsObject$lRatioTestStatistic)
+     #cat(", p-value:")
+     #cat(svarsObject$lRatioTestPValue)
+     printCoefmat(svarsObject$lRatioTest, has.Pvalue = T)
    }
   }else if(svarsObject$method == "Smooth transition"){
     cat("\nEstimated location of transition: ")
@@ -64,12 +64,10 @@ summary.svars <- function(object, ...){
     cat("\nStandard Errors of B:\n")
     print(svarsObject$B_SE)
     cat("\nPairwise Wald Test:\n")
-    print(svarsObject$wald_statistic)
-    if(svarsObject$restrictions > 0){
-      cat("\nLikelihood Ratio Test Statistic: ")
-      cat(svarsObject$lRatioTestStatistic)
-      cat(", p-value:")
-      cat(svarsObject$lRatioTestPValue)
+    printCoefmat(svarsObject$wald_statistic, has.Pvalue = T)
+    if(svarsObject$restrictions > 0 & svarsObject$lr_test == T){
+      cat("\nLikelihood Ratio Test: \n")
+      printCoefmat(svarsObject$lRatioTest, has.Pvalue = T)
 
     }
  }else if(svarsObject$method == "Non-Gaussian maximum likelihood"){
@@ -89,7 +87,12 @@ summary.svars <- function(object, ...){
    cat("\nEstimated scale of the standardized B: ")
    cat(svarsObject$sigma)
    cat("\nStandard errors of the scale:          ")
-   cat(svarsObject$sigma_SE)
+   cat(svarsObject$sigma_SE, "\n")
+   if(svarsObject$restrictions > 0){
+     cat("\nLikelihood Ratio Test: \n")
+     printCoefmat(svarsObject$lRatioTest, has.Pvalue = T)
+
+   }
 
  }else if(svarsObject$method == "Distance covariances"){
    cat("\n")
